Session

Struct Session 

pub struct Session<T>
where T: DatabasePool + Clone + Debug + Sync + Send + 'static,
{ pub(crate) store: SessionStore<T>, pub(crate) id: String, }
A Session Store.

Provides a Storage Handler to SessionStore and contains the ID of the current session.

This is Auto generated by the Session Layer Upon Service Execution.

Fields

store: SessionStore<T>

The SessionStore that holds all the Sessions.

id: String

The Sessions current ID for looking up its store.

Implementations

Source

impl<S> Session<S>
where S: DatabasePool + Clone + Debug + Sync + Send + 'static,

pub(crate) async fn new( store: SessionStore<S>, value: Option<String>, ) -> Result<(Self, bool), SessionError>

pub(crate) async fn generate_id( store: &SessionStore<S>, ) -> Result<String, SessionError>

Available on crate feature key-store only.
pub fn create_data(&self)

Sets the Session to create the SessionData based on the current Session ID. You can only use this if SessionMode::Manual is set or it will Panic. This will also set the store to true similar to session.set_store(true);

Examples
โ“˜
session.create_data();
pub fn data_exists(&self) -> bool

Checks if the SessionData was created or not.

Examples
โ“˜
if session.data_exists() {
    println!("data Exists");
}
pub fn renew(&self)

Set session flags to renew/regenerate the ID. This deletes data from the database keyed with the old ID. This helps to enhance security when logging into secure areas on a website. The current sessionโ€™s data will be stored with the new ID.

Examples
โ“˜
session.renew();
pub fn update(&self)

Sets the Session to force update the database. This will increase the Timer on the sessions store making the session live longer in the persistent database.

Examples
โ“˜
session.renew();
pub fn destroy(&self)

Sets the Current Session to be Destroyed. This will Deleted the Session and Cookies upon Response Phase.

Examples
โ“˜
session.destroy();
pub fn set_longterm(&self, longterm: bool)

Sets the Current Session to a long term expiration. Useful for Remember Me setups. This will also update the database on Response Phase.

Examples
โ“˜
session.set_longterm(true);
pub fn set_store(&self, can_store: bool)

Allows the Current Session to store. This will also update the database on Response Phase.

This is only used when SessionMode is Manual or OptIn. This will allow the Session to be stored if true. This will delete and not allow a session to be stored if false.

Examples
โ“˜
session.set_store(true);
pub fn get<T: DeserializeOwned>(&self, key: &str) -> Option<T>

Gets data from the Sessionโ€™s HashMap

Provides an Option<T> that returns the requested data from the Sessions store. Returns None if Key does not exist or if serde_json failed to deserialize.

Examples
โ“˜
let id = session.get("user-id").unwrap_or(0);

Used to get data stored within SessionDataโ€™s hashmap from a key value.

pub fn get_remove<T: DeserializeOwned>(&self, key: &str) -> Option<T>

Removes a Key from the Current Sessionโ€™s HashMap returning it.

Provides an Option<T> that returns the requested data from the Sessions store. Returns None if Key does not exist or if serde_json failed to deserialize.

Examples
โ“˜
let id = session.get_remove("user-id").unwrap_or(0);

Used to get data stored within SessionDataโ€™s hashmap from a key value.

pub fn set(&self, key: &str, value: impl Serialize)

Sets data to the Current Sessionโ€™s HashMap. This will also update the database on Response Phase.

Examples
โ“˜
session.set("user-id", 1);
pub fn remove(&self, key: &str)

Removes a Key from the Current Sessionโ€™s HashMap. Does not process the String into a Type, Just removes it. This will also update the database on Response Phase.

Examples
โ“˜
let _ = session.remove("user-id");
pub fn clear(&self)

Clears all data from the Current Sessionโ€™s HashMap instantly. This will also update the database on Response Phase.

Examples
โ“˜
session.clear();
pub async fn count(&self) -> i64

Returns a i64 count of how many Sessions exist.

If the Session is persistent it will return all sessions within the database. If the Session is not persistent it will return a count within SessionStore.

Examples
โ“˜
let count = session.count().await;
pub fn get_session_id(&self) -> String

Returns the SessionID for this Session.

Examples
โ“˜
let session_id = session.get_session_id();
pub fn get_store(&self) -> &SessionStore<S>

Returns the store for this Session.

The store contains everything that all sessions need.

Examples
โ“˜
let store = session.get_store();
pub fn get_mut_store(&mut self) -> &mut SessionStore<S>

Returns a mutable store for this Session.

The store contains everything that all sessions need.

Examples
โ“˜
let store = session.get_store_mut();
pub(crate) fn remove_request(&self)

Removes a Request from the request counter used to determine if parallel requests exist. prevents data deletion until requests == 0.

Examples
โ“˜
session.remove_request();
pub(crate) fn set_request(&self)

Removes a Request from the request counter used to determine if parallel requests exist. prevents data deletion until requests == 0.

Examples
โ“˜
session.set_request();
pub(crate) fn is_parallel(&self) -> bool

checks if a session has more than one request.

Examples
โ“˜
session.is_parallel();
pub fn verify(&self) -> Result<(), SessionError>

Available on crate feature advanced only.

checks if a session exists and if it is outdated.

Examples
โ“˜
session.verify();
pub fn update_database_expires(&self) -> Result<(), SessionError>

Available on crate feature advanced only.

Updates the sessions stored database expire time. Use this before forcing a update to the database store. will update the database expires based on if the session is longterm then configs max_lifespan. if not then configs lifespan.

THIS WILL NOT UPDATE THE DATABASE SIDE.

Examples
โ“˜
session.update_database_expires();
pub fn update_memory_expires(&self) -> Result<(), SessionError>

Available on crate feature advanced only.

Updates the Sessions In memory auto remove timer. Will prevent it from being removed for the configs set memory_lifespan.

Examples
โ“˜
session.update_memory_expires();
pub async fn force_database_update(&self) -> Result<(), SessionError>

Available on crate feature advanced only.

forces a update to the databases stored data for the session. Make sure to update the databases expire time before running this or the data could be unloaded by a request checking for outdated sessions.

Examples
โ“˜
session.force_database_update().await;
pub fn memory_remove_session(&self) -> Result<(), SessionError>

Available on crate feature advanced only.

Removes the session from the memory store if it is not parallel. If it is parallel then each parallel session will need to call this once. when all parallel sessions are dead this gets unloaded.

THIS DOES NOT CLEAR THE KEY STORE.

Examples
โ“˜
session.memory_remove_session();
pub async fn database_remove_session(&self) -> Result<(), SessionError>

Available on crate feature advanced only.

Removes the session from the Database store.

THIS DOES NOT REMOVE THE KEY STORE.

Examples
โ“˜
session.database_remove_session().await;